@@ -3,7 +3,7 @@
 %%% Created : 12 Apr 2017 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -71,6 +71,14 @@
 -type state() :: #state{}.
 -export_type([tag/0]).
 
+-dialyzer({no_match, [handle_info/2, check_size/2, insert/5, do_insert/5,
+                      do_filter/6, do_fold/6, delete_if_expired/4,
+                      delete_if_expired/2]}).
+-dialyzer({no_return, terminate/2}).
+-dialyzer({no_unused, calculate_time/2}).
+-dialyzer({[no_match, no_return], [delete_counter/1, get_counter/1,
+                                   incr_counter/1]}).
+
 %%%===================================================================
 %%% API
 %%%===================================================================
@@ -346,6 +354,11 @@ untag({nocache, Val}) -> Val;
 untag(Val) -> Val.
 
 load_nif() ->
+    case os:getenv("COVERALLS") of
+        "true" -> ok;
+        _ -> load_nif2()
+    end.
+load_nif2() ->
     Path = p1_nif_utils:get_so_path(?MODULE, [?MODULE], atom_to_list(?MODULE)),
     MaxTables = get_max_tables(),
     case erlang:load_nif(Path, MaxTables) of
@@ -578,7 +591,7 @@ do_setopts(State, Opts) ->
     end,
     NewState.
 
--spec calculate_time(binary(), integer()) -> integer().
+-spec calculate_time(atom(), integer()) -> integer().
 calculate_time(Name, Timeout) ->
     Now = current_time(),
     case ets_cache_options:life_time(Name) of
@@ -682,7 +695,7 @@ ets_delete_all_objects(Tab) ->
 	    false
     end.
 
--spec ets_select_delete(atom(), fun()) -> non_neg_integer().
+-spec ets_select_delete(atom(), ets:match_spec()) -> non_neg_integer().
 ets_select_delete(Tab, Fun) ->
     try
 	incr_counter(Tab),
